==> zhongyan-activity-service-api-1.0.6-20211206.082444-106-sources.jar: cn/com/duiba/zhongyan/activity/service/api/remoteservice/activity/RemoteActivityService.java <==
package cn.com.duiba.zhongyan.activity.service.api.remoteservice.activity;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.wolf.entity.PageRequest;
import cn.com.duiba.wolf.entity.PageResponse;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.*;
import cn.com.duiba.zhongyan.activity.service.api.param.ActivityPageParam;

/**
 * @author xuanyu
 * @description: 活动对外服务
 * @date 2021/11/25 6:05 下午
 */
@AdvancedFeignClient
public interface RemoteActivityService {

    /**
     * 根据id查询活动
     * @param id
     * @return
     */
    ActivityDTO selectById(Long id);

    /**
     * 插入一条数据
     * @param record
     * @return
     */
    Long save(ActivityDTO record);

    /**
     * 选择更新
     * @param record
     * @return
     */
    Boolean updateByIdSelective(ActivityDTO record);


    /**
     * 模版列表
     * @param pageRequest
     * @return
     */
    PageResponse<TemplateDTO> listPageTemplate(PageRequest pageRequest);

    /**
     * 分页查询活动
     * @param pageRequest
     * @return
     */
    PageResponse<ActivityDTO> listPageActivity(PageRequest pageRequest);

    /**
     * 根据条件参数查询活动
     * @param activityPageParam
     * @return
     * @throws BizException
     */
    PageResponse<ActivityDTO> listPageActivityByConditions(ActivityPageParam activityPageParam);

    /**
     * 分页查询活动--参与活动
     * @param activityDTO
     * @return
     */
    PageResponse<JoinActivityDTO> listJoinActivityPage(QueryActivityDTO activityDTO);

    /**
     * 获取活动配置的奖品信息
     * @param activityId 活动id
     * @return 活动奖品配置
     */
    PrizeConfigDTO getPrizeConfig(Long activityId) throws BizException;

    /**
     * 获取问卷配置的题目数量
     * @param activityId 活动id
     * @return 活动奖品配置
     */
    Integer getQuestionCount(Long activityId) throws BizException;

    /**
     * 获取活动的基本配置
     * @param activityId
     * @return
     * @throws BizException
     */
    BaseConfigDTO getBaseConfig(Long activityId) throws BizException;
}

==> zhongyan-activity-service-api-1.0.9-20211209.085417-11-sources.jar: cn/com/duiba/zhongyan/activity/service/api/remoteservice/activity/RemoteActivityService.java <==
package cn.com.duiba.zhongyan.activity.service.api.remoteservice.activity;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.wolf.entity.PageRequest;
import cn.com.duiba.wolf.entity.PageResponse;
import cn.com.duiba.zhongyan.activity.service.api.domain.dto.*;
import cn.com.duiba.zhongyan.activity.service.api.param.ActivityPageParam;

import java.util.List;
import java.util.Map;

/**
 * @author xuanyu
 * @description: 活动对外服务
 * @date 2021/11/25 6:05 下午
 */
@AdvancedFeignClient
public interface RemoteActivityService {

    /**
     * 根据id查询活动
     * @param id
     * @return
     */
    ActivityDTO selectById(Long id);

    /**
     * 插入一条数据
     * @param record
     * @return
     */
    Long save(ActivityDTO record);

    /**
     * 选择更新
     * @param record
     * @return
     */
    Boolean updateByIdSelective(ActivityDTO record);


    /**
     * 模版列表
     * @param pageRequest
     * @return
     */
    PageResponse<TemplateDTO> listPageTemplate(PageRequest pageRequest);

    /**
     * 分页查询活动
     * @param pageRequest
     * @return
     */
    PageResponse<ActivityDTO> listPageActivity(PageRequest pageRequest);

    /**
     * 根据条件参数查询活动
     * @param activityPageParam
     * @return
     * @throws BizException
     */
    PageResponse<ActivityDTO> listPageActivityByConditions(ActivityPageParam activityPageParam);

    /**
     * 分页查询活动--参与活动
     * @param activityDTO
     * @return
     */
    PageResponse<JoinActivityPageDTO> listJoinActivityPage(QueryActivityDTO activityDTO);

    /**
     * 获取活动配置的奖品信息
     * @param activityId 活动id
     * @return 活动奖品配置
     */
    PrizeConfigDTO getPrizeConfig(Long activityId) throws BizException;

    /**
     * 获取问卷配置的题目数量
     * @param activityId 活动id
     * @return 活动奖品配置
     */
    Integer getQuestionCount(Long activityId) throws BizException;

    /**
     * 获取活动的基本配置
     * @param activityId
     * @return
     * @throws BizException
     */
    BaseConfigDTO getBaseConfig(Long activityId) throws BizException;

    /**
     * 查询活动类型
     * @return
     */
    List<String> listActType();

    /**
     * 根据活动ID批量查询活动
     * @param ids
     * @return
     */
    List<ActivityDTO> listActivityByIds(List<Long> ids);

    /**
     * 查询活动类型
     * @return
     */
    List<ActivityTypeDTO> listActivityType();

    /**
     * 本地库获取类型
     * @return
     */
    Map<String, String> getActivityTypeMap();
}
